﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.ComponentModel;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;

namespace HeuristicLab.Clients.Hive.JobManager.Views {
  [View("Hive Job Permission List")]
  [Content(typeof(HiveItemCollection<JobPermission>), false)]
  public partial class HiveJobPermissionListView : ItemCollectionView<JobPermission> {

    private Guid hiveExperimentId;
    public Guid HiveExperimentId {
      get { return hiveExperimentId; }
      set { hiveExperimentId = value; }
    }

    public HiveJobPermissionListView() {
      InitializeComponent();
      itemsGroupBox.Text = "Permissions";
    }

    protected override JobPermission CreateItem() {
      return new JobPermission() { JobId = this.hiveExperimentId };
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();

      if (Content != null) {
        foreach (JobPermission permission in Content) {
          permission.PropertyChanged += new PropertyChangedEventHandler(permission_PropertyChanged);
        }
      }
    }

    protected override void DeregisterContentEvents() {
      base.DeregisterContentEvents();

      if (Content != null) {
        foreach (JobPermission permission in Content) {
          permission.PropertyChanged -= new PropertyChangedEventHandler(permission_PropertyChanged);
        }
      }
    }

    protected override void Content_ItemsAdded(object sender, Collections.CollectionItemsChangedEventArgs<JobPermission> e) {
      base.Content_ItemsAdded(sender, e);

      foreach (JobPermission permission in e.Items) {
        permission.PropertyChanged += new PropertyChangedEventHandler(permission_PropertyChanged);
      }
    }

    protected override void Content_ItemsRemoved(object sender, Collections.CollectionItemsChangedEventArgs<JobPermission> e) {
      foreach (JobPermission permission in e.Items) {
        permission.PropertyChanged -= new PropertyChangedEventHandler(permission_PropertyChanged);
      }
    }

    protected override void Content_CollectionReset(object sender, Collections.CollectionItemsChangedEventArgs<JobPermission> e) {
      Content_ItemsRemoved(sender, e);
    }

    void permission_PropertyChanged(object sender, PropertyChangedEventArgs e) {
      OnContentChanged();
    }
  }
}
